"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _1 = require(".");
describe('getType', function () {
    it('no payload', function () {
        var increment = _1.createAction('INCREMENT');
        var type = _1.getType(increment);
        expect(type).toBe('INCREMENT');
    });
    it('no payload alternative', function () {
        var increment = _1.createAction('INCREMENT', function () { return ({ type: 'INCREMENT' }); });
        var type = _1.getType(increment);
        expect(type).toBe('INCREMENT');
    });
    it('with payload', function () {
        var add = _1.createAction('ADD', function (amount) { return ({ type: 'ADD', payload: amount }); });
        var type = _1.getType(add);
        expect(type).toBe('ADD');
    });
    it('with payload and meta', function () {
        var notify = _1.createAction('NOTIFY', function (username, message) { return ({
            type: 'NOTIFY',
            payload: { message: username + ": " + message },
            meta: { username: username, message: message },
        }); });
        var type = _1.getType(notify);
        expect(type).toBe('NOTIFY');
    });
    it('with payload and no params', function () {
        var showNotification = _1.createAction('SHOW_NOTIFICATION', function () { return ({
            type: 'SHOW_NOTIFICATION',
            payload: 'default message',
        }); });
        var type = _1.getType(showNotification);
        expect(type).toBe('SHOW_NOTIFICATION');
    });
    it('with payload and optional param', function () {
        var showNotification = _1.createAction('SHOW_NOTIFICATION', function (message) { return ({
            type: 'SHOW_NOTIFICATION',
            payload: message,
        }); });
        var type = _1.getType(showNotification);
        expect(type).toBe('SHOW_NOTIFICATION');
    });
    it('with meta and no params', function () {
        var showError = _1.createAction('SHOW_ERROR', function () { return ({
            type: 'SHOW_ERROR',
            meta: { type: 'error' },
        }); });
        var type = _1.getType(showError);
        expect(type).toBe('SHOW_ERROR');
    });
    it('with meta and optional param', function () {
        var showError = _1.createAction('SHOW_ERROR', function (message) { return ({
            type: 'SHOW_ERROR',
            payload: message,
            meta: { type: 'error' },
        }); });
        var type = _1.getType(showError);
        expect(type).toBe('SHOW_ERROR');
    });
});
//# sourceMappingURL=get-type.spec.js.map